@@ -7,7 +7,7 @@
  */
 
 #include <string.h>
-#include "orcania.h"
+#include "../include/orcania.h"
 
 static const unsigned char base64_table[65] =
 	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
