@@ -1,9 +1,11 @@
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE
+#endif
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
 #include <stdarg.h>
-#include "orcania.h"
+#include "../include/orcania.h"
 
 /**
  * 
@@ -107,7 +109,7 @@ char * o_strdup(const char * source) {
 char * o_strndup(const char * source, size_t len) {
   char *new_str;
 
-  if (source == NULL || len < 0) {
+  if (source == NULL) {
     return NULL;
   } else {
     new_str = o_malloc(len + 1);
@@ -245,7 +247,7 @@ char * o_strrchr(const char * haystack, int c) {
   }
 }
 
-#if defined(__linux__) || defined(__GLIBC__)
+#if defined(__linux__) || defined(__GLIBC__) || defined(_WIN32)
 static char *strnstr(const char *haystack, const char *needle, size_t len) {
   int i;
   size_t needle_len;
@@ -264,6 +266,22 @@ static char *strnstr(const char *haystack, const char *needle, size_t len) {
 }
 #endif
 
+#ifdef _WIN32
+static char *strcasestr(const char *haystack, const char *needle) {
+  size_t n;
+  if (haystack == NULL || needle == NULL) {
+    return NULL;
+  }
+  n = o_strlen(needle);
+  while (*haystack) {
+    if (!strnicmp(haystack++, needle, n)) {
+      return (char *)(haystack-sizeof(char));
+    }
+  }
+  return NULL;
+}
+#endif
+
 /**
  * o_strnstr
  * a modified strnstr function that don't crash when haystack is NULL or needle us NULL
@@ -452,18 +470,15 @@ int string_array_has_value_ncase(const char ** array, const char * needle, size_
  * Check if an array of string has a specified trimmed value
  */
 int string_array_has_trimmed_value(const char ** array, const char * needle) {
-  int i, to_return;
+  int i, to_return = 0;
   char * duplicate_needle, * trimmed_needle, * duplicate_value, * trimmed_value;
   if (array != NULL && needle != NULL) {
     duplicate_needle = o_strdup(needle);
-    if (duplicate_needle == NULL) {
-      to_return = 0;
-    } else {
+    if (duplicate_needle != NULL) {
       trimmed_needle = trimwhitespace(duplicate_needle);
-      for (i=0; array[i] != NULL; i++) {
+      for (i=0; array[i] != NULL && !to_return; i++) {
         duplicate_value = o_strdup(array[i]);
         if (duplicate_value == NULL) {
-          to_return = 0;
           break;
         } else {
           trimmed_value = trimwhitespace(duplicate_value);
@@ -473,11 +488,8 @@ int string_array_has_trimmed_value(const char ** array, const char * needle) {
         }
         o_free(duplicate_value);
       }
-      to_return = 0;
     }
     o_free(duplicate_needle);
-  } else {
-    to_return = 0;
   }
   return to_return;
 }
