@@ -7,7 +7,7 @@
 #include <time.h>
 
 #include <check.h>
-#include "../src/orcania.h"
+#include "../include/orcania.h"
 
 START_TEST(test_str_replace)
 {
@@ -176,8 +176,10 @@ END_TEST
 START_TEST(test_msprintf)
 {
   char * target;
+  char tmp[100];
   target = msprintf("target1 %s %d %p", "str1", 42, NULL);
-  ck_assert_str_eq(target, "target1 str1 42 (nil)");
+  sprintf(tmp, "target1 str1 42 %p", NULL);
+  ck_assert_str_eq(target, tmp);
   o_free(target);
   ck_assert_ptr_eq(msprintf(NULL, "str1", 42, NULL), NULL);
 }
@@ -196,6 +198,41 @@ START_TEST(test_trimwhitespace)
 }
 END_TEST
 
+START_TEST(test_string_array)
+{
+	char ** array, * str_orig = "Alice,Bob,Carol,Dave,Eve,Isaac";
+	int size = split_string(str_orig, ",", &array);
+	
+	ck_assert_int_eq(size, 6);
+	ck_assert_int_eq(string_array_has_value((const char **)array, "Alice"), 1);
+	ck_assert_int_eq(string_array_has_value((const char **)array, "Mallory"), 0);
+	ck_assert_int_eq(string_array_has_value_case((const char **)array, "alice"), 1);
+	ck_assert_int_eq(string_array_has_value_case((const char **)array, "mallory"), 0);
+	ck_assert_int_eq(string_array_has_value_n((const char **)array, "Aliceeee", 5), 1);
+	ck_assert_int_eq(string_array_has_value_n((const char **)array, "Malloryyyy", 7), 0);
+	ck_assert_int_eq(string_array_has_value_ncase((const char **)array, "aliceeee", 5), 1);
+	ck_assert_int_eq(string_array_has_value_ncase((const char **)array, "malloryyyy", 7), 0);
+	
+	free_string_array(array);
+}
+END_TEST
+
+START_TEST(test_string_array_has_trimmed_value)
+{
+	char ** array, * str_orig = "Alice,Bob,Carol,Dave,Eve,Isaac", * str_match_ok = "Carol", * str_match_not_found = "Sam";
+	int size = split_string(str_orig, ",", &array);
+	
+	ck_assert_int_eq(size, 6);
+	ck_assert_int_eq(string_array_has_trimmed_value((const char **)array, str_match_ok), 1);
+	ck_assert_int_eq(string_array_has_trimmed_value((const char **)array, str_match_not_found), 0);
+	ck_assert_int_eq(string_array_has_trimmed_value((const char **)array, NULL), 0);
+	ck_assert_int_eq(string_array_has_trimmed_value(NULL, str_match_ok), 0);
+	ck_assert_int_eq(string_array_has_trimmed_value(NULL, NULL), 0);
+	
+	free_string_array(array);
+}
+END_TEST
+
 START_TEST(test_base64)
 {
   char * src = "source string", encoded[128], decoded[128];
@@ -232,6 +269,8 @@ static Suite *orcania_suite(void)
 	tcase_add_test(tc_core, test_msprintf);
 	tcase_add_test(tc_core, test_trimwhitespace);
 	tcase_add_test(tc_core, test_base64);
+	tcase_add_test(tc_core, test_string_array);
+	tcase_add_test(tc_core, test_string_array_has_trimmed_value);
 	tcase_set_timeout(tc_core, 30);
 	suite_add_tcase(s, tc_core);
 
